#!/bin/bash
#
# This routine will create Phanerozoic biodiversity time series data
# without Fourier transform plots.
#
### Create the database
echo Begin creating and populating your PD biodiversity database.
createdb sed_rock
### Create tables
psql sed_rock < pd.sql
### Fix up the .csv file and extract the desired fields
./fix_fields.bash | ./extract_fields.bash > pd.db
# Create SQL commands and load the fields into the database
awk -f load.awk pd.db | psql sed_rock
### Check number of records in pd table
echo Done populating your PD database. Now to verify the database.
echo The number of entries in your PD database is:
echo "select count(*) from pd;" | psql sed_rock
### and compare with the extracted data file
echo "The number of entries above should match this number: `wc -l pd.db | awk '{print $1}'`"
echo ""
echo Creating the following age range tables:
echo sepkoski_genera
echo g21663
echo g21663_broad
echo g30782_broad
echo g13687
echo g21663 and g21663_broad will take several hours to generate
echo You will be notified when each table is complete 
echo ""
### Generate age range tables for each diversity collection
for i in sepkoski_genera g21663 g21663_broad g30782_broad g13687; do
   cd ${i}
   echo Creating table ${i}
   ./build_range_2.bash
   echo Table ${i} done
   echo ""
   cd ..
done
echo Done developing the age range tables
### Develop time series data
echo Beginning the final step:
echo Querying the age range tables to develop time series data
echo "(This should take less than a half hour)"
echo ""
echo Querying marine environments for each collection
### MARINE
for i in g13687 g21663 g21663_broad g30782; do
   cd ${i}/query/environs_marine/
   echo Querying ${i} marine
   ./query_1.bash
   echo "1 of 5 subsets done"
   cd ../../..
done
### NEARSHORE
echo Querying nearshore environments for each collection
for i in g13687 g21663 g21663_broad g30782; do
   cd ${i}/query/environs_nearshore/
   echo Querying ${i} nearshore
   ./query_1.bash
   echo "2 of 5 subsets done"
   cd ../../..
done
### OFFSHORE
echo Querying offshore environments for each collection
for i in g13687 g21663 g21663_broad g30782; do
   cd ${i}/query/environs_offshore_deep/
   echo Querying ${i} offshore
   ./query_1.bash
   echo "3 of 5 subsets done"
   cd ../../..
done
### GBA TAXA
echo Querying taxonomic classes GBA and GBA_OTHERS for each collection
for i in g13687 g21663 g21663_broad g30782; do
   cd ${i}/query/gba/
   echo Querying ${i} GBA and GBA_OTHERS
   ./query_1.bash
   echo "4 of 5 subsets done"
   cd ../../..
done
### ALL
echo Querying all genera for each collection
for i in g13687 g21663 g21663_broad g30782; do
   cd ${i}/query/all/
   echo Querying ${i} ALL 
   ./query_1.bash
   echo "5 of 5 subsets done"
   cd ../../..
done
echo Done!
